==> 5.0.44.tar.gz: madelineproto/src/danog/MadelineProto/EventHandler.php <==
<?php

/**
 * EventHandler module.
 *
 * This file is part of MadelineProto.
 * MadelineProto is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * MadelineProto is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU General Public License along with MadelineProto.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * @author    Daniil Gentili <daniil@daniil.it>
 * @copyright 2016-2019 Daniil Gentili <daniil@daniil.it>
 * @license   https://opensource.org/licenses/AGPL-3.0 AGPLv3
 *
 * @link https://docs.madelineproto.xyz MadelineProto documentation
 */

namespace danog\MadelineProto;

/**
 * Event handler.
 */
class EventHandler extends InternalDoc
{
    /**
     * Constructor.
     *
     * @param API|null $MadelineProto MadelineProto instance
     */
    public function __construct(?API $MadelineProto)
    {
        if (!$MadelineProto) {
            return;
        }
        $this->API = $MadelineProto->API;
        $this->async = &$MadelineProto->async;
        $this->methods = &$MadelineProto->methods;
        foreach ($this->API->getMethodNamespaces() as $namespace) {
            $this->{$namespace} = new APIFactory($namespace, $this->API, $this->async);
        }
    }
}

==> 5.1.15.tar.gz: madelineproto/src/danog/MadelineProto/EventHandler.php <==
<?php

/**
 * EventHandler module.
 *
 * This file is part of MadelineProto.
 * MadelineProto is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * MadelineProto is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU General Public License along with MadelineProto.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * @author    Daniil Gentili <daniil@daniil.it>
 * @copyright 2016-2020 Daniil Gentili <daniil@daniil.it>
 * @license   https://opensource.org/licenses/AGPL-3.0 AGPLv3
 *
 * @link https://docs.madelineproto.xyz MadelineProto documentation
 */

namespace danog\MadelineProto;

/**
 * Event handler.
 */
class EventHandler extends InternalDoc
{
    /**
     * Constructor.
     *
     * @param APIWrapper|null $MadelineProto MadelineProto instance
     */
    public function __construct(?APIWrapper $MadelineProto)
    {
        if (!$MadelineProto) {
            return;
        }
        self::link($this, $MadelineProto->getFactory());
        $this->API =& $MadelineProto->getAPI();
        foreach ($this->API->getMethodNamespaces() as $namespace) {
            $this->{$namespace} = $this->exportNamespace($namespace);
        }
    }
    /**
     * Get peers where to send error reports.
     *
     * @return array|string|int
     */
    public function getReportPeers()
    {
        return [];
    }
}
